==> growingio-graphql-javasdk_2.12-0.0.1-sources.jar: io/growing/graphql/model/MeasurableAttributeResponseProjection.java <==
package io.growing.graphql.model;

import com.kobylynskyi.graphql.codegen.model.graphql.GraphQLResponseField;
import com.kobylynskyi.graphql.codegen.model.graphql.GraphQLResponseProjection;

/**
 * Response projection for MeasurableAttribute
 */
@javax.annotation.Generated(
    value = "com.kobylynskyi.graphql.codegen.GraphQLCodegen",
    date = "2020-12-22T15:45:57+0800"
)
public class MeasurableAttributeResponseProjection extends GraphQLResponseProjection {

    public MeasurableAttributeResponseProjection() {
    }

    @Override
    public MeasurableAttributeResponseProjection all$() {
        return all$(3);
    }

    @Override
    public MeasurableAttributeResponseProjection all$(int maxDepth) {
        this.id();
        this.name();
        this.valueType();
        this.typename();
        return this;
    }

    public MeasurableAttributeResponseProjection id() {
        return id(null);
    }

    public MeasurableAttributeResponseProjection id(String alias) {
        fields.add(new GraphQLResponseField("id").alias(alias));
        return this;
    }

    public MeasurableAttributeResponseProjection name() {
        return name(null);
    }

    public MeasurableAttributeResponseProjection name(String alias) {
        fields.add(new GraphQLResponseField("name").alias(alias));
        return this;
    }

    public MeasurableAttributeResponseProjection valueType() {
        return valueType(null);
    }

    public MeasurableAttributeResponseProjection valueType(String alias) {
        fields.add(new GraphQLResponseField("valueType").alias(alias));
        return this;
    }

    public MeasurableAttributeResponseProjection typename() {
        return typename(null);
    }

    public MeasurableAttributeResponseProjection typename(String alias) {
        fields.add(new GraphQLResponseField("__typename").alias(alias));
        return this;
    }


}

==> growingio-graphql-javasdk_2.12-0.0.2-sources.jar: io/growing/graphql/model/MeasurableAttributeResponseProjection.java <==
package io.growing.graphql.model;

import com.kobylynskyi.graphql.codegen.model.graphql.GraphQLResponseField;
import com.kobylynskyi.graphql.codegen.model.graphql.GraphQLResponseProjection;

/**
 * Response projection for MeasurableAttribute
 */
@javax.annotation.processing.Generated(
    value = "com.kobylynskyi.graphql.codegen.GraphQLCodegen",
    date = "2021-05-27T14:30:17+0800"
)
public class MeasurableAttributeResponseProjection extends GraphQLResponseProjection {

    public MeasurableAttributeResponseProjection() {
    }

    @Override
    public MeasurableAttributeResponseProjection all$() {
        return all$(3);
    }

    @Override
    public MeasurableAttributeResponseProjection all$(int maxDepth) {
        this.id();
        this.name();
        this.valueType();
        this.isSystem();
        this.supportedTimeGranularities();
        this.typename();
        return this;
    }

    public MeasurableAttributeResponseProjection id() {
        return id(null);
    }

    public MeasurableAttributeResponseProjection id(String alias) {
        fields.add(new GraphQLResponseField("id").alias(alias));
        return this;
    }

    public MeasurableAttributeResponseProjection name() {
        return name(null);
    }

    public MeasurableAttributeResponseProjection name(String alias) {
        fields.add(new GraphQLResponseField("name").alias(alias));
        return this;
    }

    public MeasurableAttributeResponseProjection valueType() {
        return valueType(null);
    }

    public MeasurableAttributeResponseProjection valueType(String alias) {
        fields.add(new GraphQLResponseField("valueType").alias(alias));
        return this;
    }

    public MeasurableAttributeResponseProjection isSystem() {
        return isSystem(null);
    }

    public MeasurableAttributeResponseProjection isSystem(String alias) {
        fields.add(new GraphQLResponseField("isSystem").alias(alias));
        return this;
    }

    public MeasurableAttributeResponseProjection supportedTimeGranularities() {
        return supportedTimeGranularities(null);
    }

    public MeasurableAttributeResponseProjection supportedTimeGranularities(String alias) {
        fields.add(new GraphQLResponseField("supportedTimeGranularities").alias(alias));
        return this;
    }

    public MeasurableAttributeResponseProjection typename() {
        return typename(null);
    }

    public MeasurableAttributeResponseProjection typename(String alias) {
        fields.add(new GraphQLResponseField("__typename").alias(alias));
        return this;
    }


}
